@@ -4,27 +4,29 @@
 #'
 #' @param df data.frame object to work with
 #' @param idColName name of column to add
+#' @param env environment to evaluate in.
+#' @param local_short_cut logical, if TRUE use base R on local data.
 #'
 #' @examples
 #'
-#' replyr_add_ids(data.frame(x=c('a','b')), 'id')
+#' replyr_add_ids(data.frame(x=c('a','b')), 'id', local_short_cut = FALSE)
 #'
 #' @export
-replyr_add_ids <- function(df, idColName) {
-  if(replyr_is_local_data(df)) {
-    # some source of local frame
-    df[[idColName]] <- seq_len(replyr_nrow(df))
-    return(df)
+replyr_add_ids <- function(df, idColName,
+                           env = parent.frame(),
+                           local_short_cut = TRUE) {
+  if(local_short_cut) {
+    if(replyr_is_local_data(df)) {
+      # some source of local frame
+      df[[idColName]] <- seq_len(replyr_nrow(df))
+      return(df)
+    }
   }
   if(replyr_is_Spark_data(df)) {
     if(requireNamespace('sparklyr', quietly = TRUE)) {
       return(sparklyr::sdf_with_unique_id(df, id = idColName))
     }
   }
-  # arrange all
-  collist <- paste(colnames(df), collapse=', ')
-  colsort <- paste('dplyr::arrange(df,', collist, ')')
-  df <- eval(parse(text= colsort))
   # dplyr style, throws if not ordered
   REPLYRIDCOLNAME <- NULL # indicate not an unbound variable
   row_number <- dplyr::row_number # declare not unbound function
