@@ -1,6 +1,5 @@
 ## ----setup, include=FALSE------------------------------------------------
-execute_vignette <- requireNamespace("RSQLite", quietly = TRUE) &&
-  requireNamespace("dbplyr", quietly = TRUE)
+execute_vignette <- requireNamespace("RSQLite", quietly = TRUE)
 if(execute_vignette) {
   my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
   RSQLite::initExtension(my_db)
@@ -54,31 +53,6 @@ if(!is.null(sorted)) {
                                                  sorted$columnJoinPlan)))
 }
 
-## ----render1, eval=execute_vignette--------------------------------------
-# requireNamespace checks just for strict warning hygiene in vignette
-if(!is.null(sorted)) {
-  have <- c(
-    requireNamespace('DiagrammeR', quietly = TRUE),
-    requireNamespace('htmlwidgets', quietly = TRUE),
-    requireNamespace('webshot', quietly = TRUE),
-    requireNamespace('magick', quietly = TRUE),
-    requireNamespace('grid', quietly = TRUE)
-  )
-  if(all(have)) {
-    tryCatch(
-      {
-        png <- sorted$columnJoinPlan %>%
-          makeJoinDiagramSpec() %>%
-          renderJoinDiagram()
-        if(!is.null(png)) {
-          grid::grid.raster(png)
-        }
-      },
-      error = function(e) { warning(e); NULL}
-    )
-  }
-}
-
 ## ----steps, eval=execute_vignette----------------------------------------
 if(!is.null(sorted)) {
   print("join plan execution log")
