@@ -12,41 +12,48 @@ test_that("test_gapply.R", {
 
   # User supplied window functions.  They depend on known column names and
   # the data back-end matching function names (as cumsum).
-  cumulative_sum <- . %>% arrange(order) %>% mutate(cv = cumsum(values))
-  rank_in_group <- . %>% mutate(constcol = 1) %>%
-    mutate(rank = cumsum(constcol)) %>% select(-constcol)
+  cumulative_sum <- function(d) {
+    mutate(d, cv = cumsum(values))
+  }
+  rank_in_group <- function(d) {
+    d <- mutate(d, constcol = 1)
+    d <- mutate(d, rank = cumsum(constcol))
+    select(d, -constcol)
+  }
 
   for (partitionMethod in c('group_by', 'split', 'extract')) {
     #print(partitionMethod)
     #print('cumulative sum example')
     #print(
-      d %>% gapply(
+      gapply(
+        d,
         'group',
         cumulative_sum,
         ocolumn = 'order',
         partitionMethod = partitionMethod
-     )
-    # )
+      )
+    #)
     #print('ranking example')
     #print(
-      d %>% gapply(
+      gapply(
+        d,
         'group',
         rank_in_group,
         ocolumn = 'order',
         partitionMethod = partitionMethod
-    #  )
-    )
+      )
+    #)
     #print('ranking example (decreasing)')
     #print(
-      d %>% gapply(
+      gapply(
+        d,
         'group',
         rank_in_group,
         ocolumn = 'order',
         decreasing = TRUE,
         partitionMethod = partitionMethod
       )
-   # )
-
+    #)
   }
 
 })
